#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_PREDECESSOR_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_PREDECESSOR_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/predecessor.hpp>

#endif
